cmd

package
v1.1.3-beta Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 21, 2025 License: MIT Imports: 9 Imported by: 0

Documentation

Overview

Copyright © 2025 NAME HERE <EMAIL ADDRESS>

Copyright © 2025 NAME HERE <EMAIL ADDRESS>

Copyright © 2025 NAME HERE <EMAIL ADDRESS>

TTS语音合成应用 - 根命令定义

Copyright © 2025 NAME HERE <EMAIL ADDRESS>

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute()

Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.

func SetVersionInfo

func SetVersionInfo(version, buildTime, gitCommit string)

SetVersionInfo 设置版本信息

Types

type AudioFileInfo

type AudioFileInfo struct {
	Path   string
	Name   string
	Number int // 从文件名提取的数字,用于排序
}

AudioFileInfo 音频文件信息

Jump to