Documentation
¶
Overview ¶
Copyright © 2025 NAME HERE <EMAIL ADDRESS>
Copyright © 2025 NAME HERE <EMAIL ADDRESS>
Copyright © 2025 NAME HERE <EMAIL ADDRESS>
TTS语音合成应用 - 根命令定义 ¶
Copyright © 2025 TTS App Contributors ¶
Copyright © 2025 NAME HERE <EMAIL ADDRESS>
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Execute ¶
func Execute()
Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.
func SetVersionInfo ¶
func SetVersionInfo(version, buildTime, gitCommit string)
SetVersionInfo 设置版本信息
Types ¶
type AudioFileInfo ¶
AudioFileInfo 音频文件信息
Click to show internal directories.
Click to hide internal directories.